@@ -111,7 +111,8 @@ class AjaxList(object):
             table_tag_attrs = {},
             tr_tag_attrs = lambda instance: {},
             filter_form = None,
-            custom_table_foot_template = None
+            custom_table_foot_template = None,
+            show_records_count = None
         ):
         
         # ===== SET INSTANCE PROPERTIES =====
@@ -134,6 +135,7 @@ class AjaxList(object):
         self.tr_tag_attrs = tr_tag_attrs
         self.filter_form = filter_form
         self.custom_table_foot_template = custom_table_foot_template
+        self.show_records_count = show_records_count or AJAX_LIST_SETTINGS['SHOW_RECORDS_COUNT']
         
         # ===== FILTER QUERYSET =====
         if self.filter_form:
@@ -162,9 +164,7 @@ class AjaxList(object):
     def head(self):
         context = {
             'fields': self.fields,
-            'order_by': self.order_by,
-            'SORT_ASC_ELEMENT': AJAX_LIST_SETTINGS['SORT_ASC_ELEMENT'],
-            'SORT_DESC_ELEMENT': AJAX_LIST_SETTINGS['SORT_DESC_ELEMENT']
+            'order_by': self.order_by
         }
         return render_to_response('ajax_model_listing/list_head.html', context).content
     
@@ -222,6 +222,7 @@ class AjaxList(object):
             'PAGE_PREVIOUS_ELEMENT': AJAX_LIST_SETTINGS['PAGE_PREVIOUS_ELEMENT'],
             'PAGE_NEXT_ELEMENT': AJAX_LIST_SETTINGS['PAGE_NEXT_ELEMENT'],
             'PAGE_LAST_ELEMENT': AJAX_LIST_SETTINGS['PAGE_LAST_ELEMENT'],
+            'SHOW_RECORDS_COUNT': self.show_records_count,
         }
         foot_template = self.custom_table_foot_template or 'ajax_model_listing/list_foot.html'
         return render_to_response(foot_template, context).content
